==> digikam-0.10.0.tar.bz2: digikam-0.10.0/utilities/hotplug/digikam-mount-and-download.desktop.cmake <==
[Desktop Action digiKam Mount and Download]
Exec=@digikamhelperdir@/digikam-camera storage %u
Icon=digikam
Name=Download Photos with digiKam
Name[ca]=Descàrrega de fotos amb el digiKam
Name[cs]=Stáhnout fotografie pomocí digiKamu
Name[da]=Download fotografier med digiKam
Name[de]=Fotos mit digiKam herunterladen
Name[el]=Λήψη φωτογραφιών με το digiKam
Name[et]=Fotode allalaadimine digiKamiga
Name[fi]=Lataa valokuvat digiKamilla
Name[fr]=Télécharger des photos avec Digikam
Name[gl]=Descargar Fotos con digiKam
Name[is]=Hala niður myndum með digiKam
Name[it]=Scarica foto con digiKam
Name[ja]=digiKam で写真をダウンロード
Name[km]=ទាញយក​រូបថត​ដោយ digiKam
Name[lt]=Atsisiųsti nuotraukas su digiKam
Name[lv]=Ielādēt fotogrāfijas ar digiKam
Name[nb]=Last ned fotografier med digiKam
Name[nds]=Fotos mit digiKam daalladen
Name[nl]=Foto's met digiKam downloaden
Name[pa]=ਡਿਜਿਕੈਮ ਨਾਲ ਫੋਟੋ ਡਾਊਨਲੋਡ ਕਰੋ
Name[pl]=Pobierz zdjęcia za pomocą digiKam
Name[pt]=Obter Fotos com o digiKam
Name[pt_BR]=Baixar as fotos com o digiKam
Name[ro]=Descărcare de fotografii cu digiKam
Name[ru]=Скопировать фотографии в альбом digiKam
Name[sk]=Stiahnuť fotografie pomocou digiKam
Name[sv]=Ladda ner foton med Digikam
Name[th]=ดาวน์โหลดภาพถ่ายด้วย digiKam
Name[tr]=Fotoğrafları DigiKam ile İndir
Name[uk]=Завантажити фотографії програмою digiKam
Name[x-test]=xxDownload Photos with digiKamxx
Name[zh_CN]=用 digiKam 下载照片

[Desktop Entry]
Encoding=UTF-8
Type=Service
Actions=digiKam Mount and Download;
ServiceTypes=KonqPopupMenu/Plugin,media/removable_unmounted,media/camera_unmounted

==> digikam-1.2.0.tar.bz2: digikam-1.2.0/utilities/hotplug/digikam-mount-and-download.desktop.cmake <==
[Desktop Action digiKam Mount and Download]
Exec=@digikamhelperdir@/digikam-camera storage %u
Icon=digikam
Name=Download Photos with digiKam
Name[bg]=Изтегляне на снимки с digiKam
Name[ca]=Descarrega les fotos amb el digiKam
Name[ca@valencia]=Descarrega les fotos amb el digiKam
Name[cs]=Stáhnout fotografie pomocí digiKamu
Name[da]=Download fotografier med digiKam
Name[de]=Fotos mit digiKam herunterladen
Name[el]=Λήψη φωτογραφιών με το digiKam
Name[en_GB]=Download Photos with digiKam
Name[es]=Descargar fotos con digiKam
Name[et]=Fotode allalaadimine digiKamiga
Name[fi]=Siirrä valokuvat digiKamilla
Name[fr]=Télécharger des photos avec digiKam
Name[gl]=Descargar fotos con digiKam
Name[hne]=डिजिकैम के साथ फोटो डाउनलोड करव
Name[hr]=Preuzmi fotografije digiKamom
Name[is]=Hala niður myndum með digiKam
Name[it]=Scarica foto con digiKam
Name[ja]=digiKam で写真をダウンロード
Name[km]=ទាញយក​រូបថត​ដោយ digiKam
Name[lt]=Atsisiųsti nuotraukas su digiKam
Name[lv]=Ielādēt fotogrāfijas ar digiKam
Name[nb]=Last ned fotografier med digiKam
Name[nl]=Foto's met digiKam downloaden
Name[nn]=Last ned foto med digiKam
Name[pa]=ਡਿਜਿਕੈਮ ਨਾਲ ਫੋਟੋ ਡਾਊਨਲੋਡ ਕਰੋ
Name[pl]=Pobierz zdjęcia za pomocą digiKam
Name[pt]=Obter Fotos com o digiKam
Name[pt_BR]=Transferir as fotos com o digiKam
Name[ro]=Descărcare de fotografii cu digiKam
Name[ru]=Скопировать фотографии в альбом digiKam
Name[sk]=Stiahnuť fotografie pomocou digiKam
Name[sv]=Ladda ner foton med Digikam
Name[th]=ดาวน์โหลดภาพถ่ายด้วย digiKam
Name[tr]=Fotoğrafları DigiKam ile İndir
Name[uk]=Звантажити фотографії програмою digiKam
Name[x-test]=xxDownload Photos with digiKamxx
Name[zh_CN]=用 digiKam 下载照片
Name[zh_TW]=使用 digiKam 下載照片

[Desktop Entry]
Encoding=UTF-8
Type=Service
Actions=digiKam Mount and Download;
ServiceTypes=KonqPopupMenu/Plugin,media/removable_unmounted,media/camera_unmounted
